@@ -75,12 +75,20 @@ class Breed:
                 # Sleep 10s while waiting
                 sleep(10)
                 logging.info(f"Waiting for transactions '{self}' to finish (Nonce: {nonce})...")
+            except ValueError as err:
+                if 'receipts not found by' in err.args[0]['message']:
+                    logging.info("Could not find TX, giving it a bit more time.")
+                    sleep(20)
+                else:
+                    logging.warning(f"Important: Error occurred trying to find recepit for transaction '{self}'.\n"
+                                    f"Error given: {err}.")
+                    return
 
         if success:
-            logging.info(f"{self} completed successfully")
+            logging.info(f"Important: {self} completed successfully")
             return _hash
         else:
-            logging.info(f"{self} failed")
+            logging.info(f"Important: {self} failed")
 
     def __str__(self):
         return (f"Breeding axie {self.sire_axie} with {self.matron_axie} in account "
@@ -131,13 +139,17 @@ class TrezorBreed:
             data=data,
             chain_id=2020
         )
+        l_sig = list(sig)
+        l_sig[1] = l_sig[1].lstrip(b'\x00')
+        l_sig[2] = l_sig[2].lstrip(b'\x00')
+        sig = tuple(l_sig)
         transaction = rlp.encode((nonce, self.w3.toWei('1', 'gwei'), self.gas, to, 0, data) + sig)
         # Send raw transaction
         self.w3.eth.send_raw_transaction(transaction)
         # get transaction _hash
         _hash = self.w3.toHex(self.w3.keccak(transaction))
         # Wait for transaction to finish or timeout
-        logging.info("{self} about to start!")
+        logging.info(f"{self} about to start!")
         start_time = datetime.now()
         while True:
             # We will wait for max 10minutes for this tx to respond
@@ -156,12 +168,20 @@ class TrezorBreed:
                 # Sleep 10s while waiting
                 sleep(10)
                 logging.info(f"Waiting for transactions '{self}' to finish (Nonce: {nonce})...")
+            except ValueError as err:
+                if 'receipts not found by' in err.args[0]['message']:
+                    logging.info("Could not find TX, giving it a bit more time.")
+                    sleep(20)
+                else:
+                    logging.warning(f"Important: Error occurred trying to find recepit for transaction '{self}'.\n"
+                                    f"Error given: {err}.")
+                    return
 
         if success:
-            logging.info(f"{self} completed successfully")
+            logging.info(f"Important: {self} completed successfully")
             return _hash
         else:
-            logging.info(f"{self} failed")
+            logging.info(f"Important: {self} failed")
             return
 
     def __str__(self):
