@@ -91,7 +91,7 @@ class Scatter:
 
         # Check enough balance is present
         if not check_balance(self.from_acc, self.token) >= sum(self.amounts_list) and check_balance(self.from_acc, 'ron') >= self.w3.toWei(0.00001, 'ether'):
-            logging.warning("Not enough {TOKEN[self.token]} balance or not enough RON to pay for the tx")
+            logging.warning(f"Important: Not enough {TOKEN[self.token]} balance or not enough RON to pay for the tx")
             return
         
         # Get Nonce
@@ -123,7 +123,7 @@ class Scatter:
             # We will wait for max 5minutes for this tx to respond, if it does not, we will re-try
             if datetime.now() - start_time > timedelta(minutes=TIMEOUT_MINS):
                 success = False
-                logging.info(f"Transaction {self}, timed out!")
+                logging.info(f"Important:Transaction {self}, timed out!")
                 break
             try:
                 recepit = self.w3.eth.get_transaction_receipt(_hash)
@@ -136,20 +136,28 @@ class Scatter:
                 # Sleep 10s while waiting
                 logging.info(f"Waiting for transaction '{self}' to finish (Nonce:{nonce})...")
                 sleep(10)
+            except ValueError as err:
+                if 'receipts not found by' in err.args[0]['message']:
+                    logging.info("Could not find TX, giving it a bit more time.")
+                    sleep(20)
+                else:
+                    logging.warning(f"Important: Error occurred trying to find recepit for transaction '{self}'.\n"
+                                    f"Error given: {err}.")
+                    return
 
         if success:
-            logging.info(f"Transaction {self} completed! hash: {_hash} - "
-                        f"Explorer: https://explorer.roninchain.com/tx/{str(_hash)}")
+            logging.info(f"Important: Transaction {self} completed! hash: {_hash} - "
+                         f"Explorer: https://explorer.roninchain.com/tx/{str(_hash)}")
             return _hash
         else:
-            logging.info(f"Transaction {self} failed. Trying to augment gas price to unstuck it.")
+            logging.info(f"Important: Transaction {self} failed. Trying to augment gas price to unstuck it.")
             self.increase_gas_tx(nonce)
     
     
     def execute_ron(self, gas_price=1, nonce=None):
         # Check enough balance is present
         if not self.w3.toWei(check_balance(self.from_acc, 'ron'), 'ether') >= (sum(self.amounts_list) + self.w3.toWei(0.00001, 'ether')):
-            logging.warning("Not enough RON balance to scatter and pay the tx.")
+            logging.warning("Important: Not enough RON balance to scatter and pay the tx.")
             return
                 
         # Get Nonce
@@ -163,8 +171,10 @@ class Scatter:
             "chainId": 2020,
             "gas": 1000000,
             "gasPrice": self.w3.toWei(str(gas_price), "gwei"),
-            "nonce": nonce
+            "nonce": nonce,
+            "value": sum(self.amounts_list)
         })
+        logging.debug(f'DEBUG: {transaction}. \n to_list: {self.to_list}   \n amounts_list: {self.amounts_list}')
         # Sign Transaction
         signed = self.w3.eth.account.sign_transaction(
             transaction,
@@ -180,7 +190,7 @@ class Scatter:
             # We will wait for max 5minutes for this tx to respond, if it does not, we will re-try
             if datetime.now() - start_time > timedelta(minutes=TIMEOUT_MINS):
                 success = False
-                logging.info(f"Transaction {self}, timed out!")
+                logging.info(f"Important: Transaction {self}, timed out!")
                 break
             try:
                 recepit = self.w3.eth.get_transaction_receipt(_hash)
@@ -193,13 +203,21 @@ class Scatter:
                 # Sleep 10s while waiting
                 logging.info(f"Waiting for transaction '{self}' to finish (Nonce:{nonce})...")
                 sleep(10)
+            except ValueError as err:
+                if 'receipts not found by' in err.args[0]['message']:
+                    logging.info("Could not find TX, giving it a bit more time.")
+                    sleep(20)
+                else:
+                    logging.warning(f"Important: Error occurred trying to find recepit for transaction '{self}'.\n"
+                                    f"Error given: {err}.")
+                    return
 
         if success:
-            logging.info(f"Transaction {self} completed! hash: {_hash} - "
-                        f"Explorer: https://explorer.roninchain.com/tx/{str(_hash)}")
+            logging.info(f"Important: Transaction {self} completed! hash: {_hash} - "
+                         f"Explorer: https://explorer.roninchain.com/tx/{str(_hash)}")
             return _hash
         else:
-            logging.info(f"Transaction {self} failed. Trying to augment gas price to unstuck it.")
+            logging.info(f"Important: Transaction {self} failed. Trying to augment gas price to unstuck it.")
             self.increase_gas_tx(nonce)
 
     def execute(self, gas_price=1, nonce=None):
@@ -270,6 +288,10 @@ class TrezorScatter:
             data=data,
             chain_id=2020
         )
+        l_sig = list(sig)
+        l_sig[1] = l_sig[1].lstrip(b'\x00')
+        l_sig[2] = l_sig[2].lstrip(b'\x00')
+        sig = tuple(l_sig)
         transaction = rlp.encode((nonce, self.w3.toWei(1, "gwei"), 1000000, to, 0, data) + sig)
         self.w3.eth.send_raw_transaction(transaction)
         approve_hash = self.w3.toHex(self.w3.keccak(transaction))
@@ -290,14 +312,14 @@ class TrezorScatter:
     def execute_token(self, gas_price=1, nonce=None):
         # Check token is approved
         if not self.is_contract_accepted():
-            logging.warning(f"Token {self.token} is not approved to use scatter, "
+            logging.warning(f"Important: Token {self.token} is not approved to use scatter, "
                             "you can re-try or manually accept it on "
                             "scatter website (https://scatter.roninchain.com/).")
             return
 
         # Check enough balance is present
         if not check_balance(self.from_acc, self.token) >= (sum(self.amounts_list) and check_balance(self.from_acc, 'ron') >= self.w3.toWei(0.00001, 'ether')):
-            logging.warning("Not enough {TOKEN[self.token]} balance or not enough RON to pay for the tx")
+            logging.warning(f"Important: Not enough {TOKEN[self.token]} balance or not enough RON to pay for the tx")
             return
         
         # Get Nonce
@@ -327,6 +349,10 @@ class TrezorScatter:
             data=data,
             chain_id=2020
         )
+        l_sig = list(sig)
+        l_sig[1] = l_sig[1].lstrip(b'\x00')
+        l_sig[2] = l_sig[2].lstrip(b'\x00')
+        sig = tuple(l_sig)
         transaction = rlp.encode((nonce, self.w3.toWei(str(gas_price), "gwei"), 1000000, to, 0, data) + sig)
         # Send raw transaction
         self.w3.eth.send_raw_transaction(transaction)
@@ -337,7 +363,7 @@ class TrezorScatter:
             # We will wait for max 5minutes for this tx to respond, if it does not, we will re-try
             if datetime.now() - start_time > timedelta(minutes=TIMEOUT_MINS):
                 success = False
-                logging.info(f"Transaction {self}, timed out!")
+                logging.info(f"Important: Transaction {self}, timed out!")
                 break
             try:
                 recepit = self.w3.eth.get_transaction_receipt(_hash)
@@ -350,13 +376,21 @@ class TrezorScatter:
                 # Sleep 10s while waiting
                 logging.info(f"Waiting for transaction '{self}' to finish (Nonce:{nonce})...")
                 sleep(10)
+            except ValueError as err:
+                if 'receipts not found by' in err.args[0]['message']:
+                    logging.info("Could not find TX, giving it a bit more time.")
+                    sleep(20)
+                else:
+                    logging.warning(f"Important: Error occurred trying to find recepit for transaction '{self}'.\n"
+                                    f"Error given: {err}.")
+                    return
 
         if success:
-            logging.info(f"Transaction {self} completed! hash: {_hash} - "
-                        f"Explorer: https://explorer.roninchain.com/tx/{str(_hash)}")
+            logging.info(f"Important: Transaction {self} completed! hash: {_hash} - "
+                         f"Explorer: https://explorer.roninchain.com/tx/{str(_hash)}")
             return _hash
         else:
-            logging.info(f"Transaction {self} failed. Trying to augment gas price to unstuck it.")
+            logging.info(f"Important: Transaction {self} failed. Trying to augment gas price to unstuck it.")
             self.increase_gas_tx(nonce)
     
     
@@ -377,7 +411,8 @@ class TrezorScatter:
             "chainId": 2020,
             "gas": 1000000,
             "gasPrice": self.w3.toWei(str(gas_price), "gwei"),
-            "nonce": nonce
+            "nonce": nonce,
+            "value": sum(self.amounts_list)
         })
         data = self.w3.toBytes(hexstr=transaction['data'])
         to = self.w3.toBytes(hexstr=SCATTER_CONTRACT)
@@ -388,10 +423,14 @@ class TrezorScatter:
             gas_price=self.w3.toWei(str(gas_price), "gwei"),
             gas_limit=1000000,
             to=SCATTER_CONTRACT,
-            value=0,
+            value=sum(self.amounts_list),
             data=data,
             chain_id=2020
         )
+        l_sig = list(sig)
+        l_sig[1] = l_sig[1].lstrip(b'\x00')
+        l_sig[2] = l_sig[2].lstrip(b'\x00')
+        sig = tuple(l_sig)
         transaction = rlp.encode((nonce, self.w3.toWei(str(gas_price), "gwei"), 1000000, to, 0, data) + sig)
         # Send raw transaction
         self.w3.eth.send_raw_transaction(transaction)
@@ -402,7 +441,7 @@ class TrezorScatter:
             # We will wait for max 5minutes for this tx to respond, if it does not, we will re-try
             if datetime.now() - start_time > timedelta(minutes=TIMEOUT_MINS):
                 success = False
-                logging.info(f"Transaction {self}, timed out!")
+                logging.info(f"Important: Transaction {self}, timed out!")
                 break
             try:
                 recepit = self.w3.eth.get_transaction_receipt(_hash)
@@ -415,13 +454,21 @@ class TrezorScatter:
                 # Sleep 10s while waiting
                 logging.info(f"Waiting for transaction '{self}' to finish (Nonce:{nonce})...")
                 sleep(10)
+            except ValueError as err:
+                if 'receipts not found by' in err.args[0]['message']:
+                    logging.info("Could not find TX, giving it a bit more time.")
+                    sleep(20)
+                else:
+                    logging.warning(f"Important: Error occurred trying to find recepit for transaction '{self}'.\n"
+                                    f"Error given: {err}.")
+                    return
 
         if success:
-            logging.info(f"Transaction {self} completed! hash: {_hash} - "
-                        f"Explorer: https://explorer.roninchain.com/tx/{str(_hash)}")
+            logging.info(f"Important: Transaction {self} completed! hash: {_hash} - "
+                         f"Explorer: https://explorer.roninchain.com/tx/{str(_hash)}")
             return _hash
         else:
-            logging.info(f"Transaction {self} failed. Trying to augment gas price to unstuck it.")
+            logging.info(f"Important: Transaction {self} failed. Trying to augment gas price to unstuck it.")
             self.increase_gas_tx(nonce)
 
     def execute(self, gas_price=1, nonce=None):
